@@ -1,16 +1,17 @@
 from adaptive_scheduler import client_support, scheduler, server_support, utils
 from adaptive_scheduler._version import __version__
 from adaptive_scheduler.scheduler import PBS, SLURM
-from adaptive_scheduler.server_support import RunManager, slurm_run
+from adaptive_scheduler.server_support import RunManager, slurm_run, start_one_by_one
 
 __all__ = [
+    "__version__",
     "client_support",
     "PBS",
     "RunManager",
     "scheduler",
     "server_support",
-    "SLURM",
-    "utils",
     "slurm_run",
-    "__version__",
+    "SLURM",
+    "start_one_by_one",
+    "utils",
 ]
